@@ -1,28 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-zkCli.sh clone.
-It supports the basic ops plus a few handy extensions:
- (CONNECTED) /> ls
- zookeeper
- (CONNECTED) /> create foo 'bar'
- (CONNECTED) /> get foo
- bar
- (CONNECTED) /> cd foo
- (CONNECTED) /foo> create ish 'barish'
- (CONNECTED) /foo> cd ..
- (CONNECTED) /> ls foo
- ish
- (CONNECTED) /> create temp- 'temp' true true
- (CONNECTED) /> ls
- zookeeper foo temp-0000000001
- (CONNECTED) /> rmr foo
- (CONNECTED) />
- (CONNECTED) /> tree
- .
- ├── zookeeper
- │   ├── config
- │   ├── quota
+A powerful & scriptable ZooKeeper shell
 """
 
 from __future__ import print_function
@@ -40,6 +19,7 @@ import time
 import zlib
 
 from kazoo.exceptions import (
+    AuthFailedError,
     BadArgumentsError,
     BadVersionError,
     ConnectionLoss,
@@ -98,6 +78,8 @@ def connected(func):
         else:
             try:
                 return func(*args, **kwargs)
+            except AuthFailedError:
+                self.show_output("Authentication failed.")
             except NoAuthError:
                 self.show_output("Not authenticated.")
             except ConnectionLoss:
@@ -234,6 +216,8 @@ class Shell(XCmd):
         """
         Authenticates the session
 
+        add_auth <scheme> <credential>
+
         Examples:
 
         > add_auth digest super:s3cr3t
@@ -246,30 +230,41 @@ class Shell(XCmd):
         return complete(completers, cmd_param_text, full_cmd, *rest)
 
     @connected
-    @ensure_params(Required("path"), Multi("acls"))
+    @ensure_params(Required("path"), Required("acls"), BooleanOptional("recursive"))
     @check_paths_exists("path")
     def do_set_acls(self, params):
         """
         Sets ACLs for a given path
 
+        set_acls <path> <acls> [recursive]
+
         Examples:
 
-        > set_acls /some/path world:anyone:r digest:user:aRxISyaKnTP2+OZ9OmQLkq04bvo=:cdrwa
-        > set_acls /some/path world:anyone:r username_password:user:p@ass0rd:cdrwa
+        > set_acls /some/path 'world:anyone:r digest:user:aRxISyaKnTP2+OZ9OmQLkq04bvo=:cdrwa'
+        > set_acls /some/path 'world:anyone:r username_password:user:p@ass0rd:cdrwa'
+        > set_acls /path 'world:anyone:r' true
 
         """
         try:
-            acls = ACLReader.extract(params.acls)
+            acls = ACLReader.extract(shlex.split(params.acls))
         except ACLReader.BadACL as ex:
             self.show_output("Failed to set ACLs: %s.", ex)
             return
 
-        try:
-            self._zk.set_acls(params.path, acls)
-        except (NoNodeError, BadVersionError, InvalidACLError, ZookeeperError) as ex:
-            self.show_output("Failed to set ACLs: %s. Error: %s", str(acls), str(ex))
+        def set_acls(path):
+            try:
+                self._zk.set_acls(path, acls)
+            except (NoNodeError, BadVersionError, InvalidACLError, ZookeeperError) as ex:
+                self.show_output("Failed to set ACLs: %s. Error: %s", str(acls), str(ex))
+
+        if params.recursive:
+            for cpath, _ in self._zk.tree(params.path, 0, full_path=True):
+                set_acls(cpath)
+
+        set_acls(params.path)
 
     def complete_set_acls(self, cmd_param_text, full_cmd, *rest):
+        """ FIXME: complete inside a quoted param is broken """
         possible_acl = [
             "digest:",
             "username_password:",
@@ -280,8 +275,7 @@ class Shell(XCmd):
             "world:anyone:cdrwa",
         ]
         complete_acl = partial(complete_values, possible_acl)
-        complete_many = [complete_acl for i in range(0, 10)]  # 10 ACLs is probably enough
-        completers = [self._complete_path] + complete_many
+        completers = [self._complete_path, complete_acl, complete_boolean]
         return complete(completers, cmd_param_text, full_cmd, *rest)
 
     @connected
@@ -417,8 +411,7 @@ class Shell(XCmd):
         where src and dst can be:
 
            /some/path (in the connected server)
-           file://<path>
-           zk://[user:passwd@]host/<path>
+           zk://[scheme:user:passwd@]host/<path>
            json://!some!path!backup.json/some/path
 
         with a few restrictions. Given the semantic differences that znodes have with filesystem
@@ -428,11 +421,14 @@ class Shell(XCmd):
         Examples:
 
         > cp /some/znode /backup/copy-znode  # local
-        > cp file://<path> zk://[user:passwd@]host/<path> <recursive> <overwrite> <async> <verbose> <max_items>
+        > cp /some/znode zk://digest:bernie:pasta@10.0.0.1/backup true true
         > cp /some/path json://!home!user!backup.json/ true true
 
         """
-        self.copy(params, params.recursive, params.overwrite, params.max_items, False)
+        try:
+            self.copy(params, params.recursive, params.overwrite, params.max_items, False)
+        except AuthFailedError:
+            self.show_output("Authentication failed.")
 
     def complete_cp(self, cmd_param_text, full_cmd, *rest):
         complete_max = partial(complete_values, [str(i) for i in range(0, 11)])
@@ -463,7 +459,6 @@ class Shell(XCmd):
         where src and dst can be:
 
            /some/path (in the connected server)
-           file://<path>
            zk://[user:passwd@]host/<path>
            json://!some!path!backup.json/some/path
 
@@ -477,7 +472,6 @@ class Shell(XCmd):
         Examples:
 
         > mirror /some/znode /backup/copy-znode  # local
-        > mirror file://<path> zk://[user:passwd@]host/<path> <async> <verbose> <max_items>
         > mirror /some/path json://!home!user!backup.json/ true true
 
         """
