@@ -79,41 +79,11 @@ class CpCmdsTestCase(ShellTestCase):
         bad_path = "%s/doesnt/exist/path" % (self.tests_path)
         self.shell.onecmd("cp %s %s true true" % (
             bad_path, "%s/some/other/nonexistent/path" % (self.tests_path)))
-        expected_output = "znode %s in 127.0.0.1:2181 doesn't exist\n" % (
-            bad_path)
-        self.assertIn(expected_output, self.output.getvalue())
+        self.assertIn("doesn't exist\n", self.output.getvalue())
 
-    def test_cp_file2zk(self):
-        # FIXME: everything should be treated as binary, expecting strings in ZK
-        #        breaks badly (i.e.: serialized thrift, etc.).
-        return
-
-        myfile = "%s/myfile" % (self.temp_dir)
-        with open(myfile, "w") as fph:
-            fph.writelines(["hello\n", "bye\n"])
-
-        src_path = "file://%s" % (myfile)
-        dst_path = "%s/myfile" % (self.tests_path)
-        self.shell.onecmd("cp %s %s true true" % (src_path, dst_path))
-        self.shell.onecmd("get %s" % (dst_path))
-        expected_output =  u"hello\nbye\n\n"
-        self.assertEqual(expected_output, self.output.getvalue())
-
-    def test_cp_zk2file(self):
-        # FIXME: everything should be treated as binary, expecting strings in ZK
-        #        breaks badly (i.e.: serialized thrift, etc.).
-        return
-
-        src_path = "%s/src" % (self.tests_path)
-        myfile = "%s/myfile" % (self.temp_dir)
-        dst_path = "file://%s" % (myfile)
-        self.shell.onecmd("create %s 'HELLO'" % (src_path))
-        self.shell.onecmd("cp %s %s false true false true" % (src_path, dst_path))
-        content = ""
-        with open(myfile, "r") as fph:
-            content = "".join(fph.readlines())
-
-        self.assertEqual(content, "HELLO")
+    def test_bad_auth(self):
+        self.shell.onecmd("cp / zk://foo:bar@localhost/y")
+        self.assertTrue(True)
 
     ###
     # Helpers.
